@@ -7,9 +7,10 @@ from rest_framework.exceptions import ValidationError
 from rest_polymorphic.serializers import PolymorphicSerializer
 
 from .models import (DOCUMENT_CLASSIFICATION, IMAGE_CLASSIFICATION, SEQ2SEQ,
-                     SEQUENCE_LABELING, SPEECH2TEXT, AutoLabelingConfig,
-                     Category, Comment, Example, ImageClassificationProject,
-                     Label, Project, Role, RoleMapping, Seq2seqProject,
+                     SEQUENCE_LABELING, SPEECH2TEXT, AnnotationRelations,
+                     AutoLabelingConfig, Category, Comment, Example,
+                     ExampleState, ImageClassificationProject, Label, Project,
+                     RelationTypes, Role, RoleMapping, Seq2seqProject,
                      SequenceLabelingProject, Span, Speech2textProject, Tag,
                      TextClassificationProject, TextLabel)
 
@@ -18,7 +19,7 @@ class UserSerializer(serializers.ModelSerializer):
 
     class Meta:
         model = get_user_model()
-        fields = ('id', 'username', 'is_superuser')
+        fields = ('id', 'username', 'is_superuser', 'is_staff')
 
 
 class LabelSerializer(serializers.ModelSerializer):
@@ -81,6 +82,7 @@ class TagSerializer(serializers.ModelSerializer):
 class ExampleSerializer(serializers.ModelSerializer):
     annotations = serializers.SerializerMethodField()
     annotation_approver = serializers.SerializerMethodField()
+    is_confirmed = serializers.SerializerMethodField()
 
     def get_annotations(self, instance):
         request = self.context.get('request')
@@ -98,6 +100,16 @@ class ExampleSerializer(serializers.ModelSerializer):
         approver = instance.annotations_approved_by
         return approver.username if approver else None
 
+    def get_is_confirmed(self, instance):
+        user = self.context.get('request').user
+        if instance.project.collaborative_annotation:
+            current_user_role = RoleMapping.objects.get(user_id=user.id, project_id=instance.project.id).role
+            state_ids = [state.id for state in instance.states.all() if state.confirmed_user_role == current_user_role]
+            states = instance.states.filter(id__in=state_ids)
+        else:
+            states = instance.states.filter(confirmed_by_id=user.id)
+        return states.count() > 0
+
     class Meta:
         model = Example
         fields = [
@@ -107,9 +119,18 @@ class ExampleSerializer(serializers.ModelSerializer):
             'meta',
             'annotation_approver',
             'comment_count',
-            'text'
+            'text',
+            'is_confirmed'
         ]
-        read_only_fields = ['filename']
+        read_only_fields = ['filename', 'is_confirmed']
+
+
+class ExampleStateSerializer(serializers.ModelSerializer):
+
+    class Meta:
+        model = ExampleState
+        fields = ('id', 'example', 'confirmed_by')
+        read_only_fields = ('id', 'example', 'confirmed_by')
 
 
 class ApproverSerializer(ExampleSerializer):
@@ -172,6 +193,7 @@ class SequenceLabelingProjectSerializer(ProjectSerializer):
 
     class Meta(ProjectSerializer.Meta):
         model = SequenceLabelingProject
+        fields = ProjectSerializer.Meta.fields + ('allow_overlapping', 'grapheme_mode')
 
 
 class Seq2seqProjectSerializer(ProjectSerializer):
@@ -327,3 +349,23 @@ def get_annotation_serializer(task: str):
         return mapping[task]
     except KeyError:
         raise ValueError(f'{task} is not implemented.')
+
+
+class RelationTypesSerializer(serializers.ModelSerializer):
+
+    def validate(self, attrs):
+        return super().validate(attrs)
+
+    class Meta:
+        model = RelationTypes
+        fields = ('id', 'color', 'name')
+
+
+class AnnotationRelationsSerializer(serializers.ModelSerializer):
+
+    def validate(self, attrs):
+        return super().validate(attrs)
+
+    class Meta:
+        model = AnnotationRelations
+        fields = ('id', 'annotation_id_1', 'annotation_id_2', 'type', 'user', 'timestamp')
