@@ -1,7 +1,7 @@
 import abc
 from typing import Dict
 
-from pydantic import BaseModel
+from pydantic import BaseModel, validator
 
 
 class BaseData(BaseModel, abc.ABC):
@@ -19,6 +19,13 @@ class BaseData(BaseModel, abc.ABC):
 class TextData(BaseData):
     text: str
 
+    @validator('text')
+    def text_is_not_empty(cls, value: str):
+        if value:
+            return value
+        else:
+            raise ValueError('is not empty.')
+
 
 class FileData(BaseData):
     pass
